<?php
namespace Backend\Controller;

use Backend\Controller\BackendController;
use Backend\Model\CloudstorageModel as CSM;
use Common\Respository\CloudstorageBusinessRespository as CSBR;
use Common\Data\GiantAPIParamsData as GD;

/**
 * 会员管理
 * @author: duanbin
 * @时间: 2016年10月21日 下午3:35:10
 */
class CloudstorageController extends BackendController{
	/**
	 * 用户列表
	 */
	public function index(){
		$model = new CSM();
		$respository = new CSBR($model);
		//表头，排序相关数据
		$th = $model->getSortable();
		//获取表头里面真正有排序的字段
		$sorted = $model->getSortableField($th);
		//未加排序前缀的表头
		$th_raw = array_keys($model->sortable);
		//获取筛选字段的需要的数据,筛选所需要的字段
		$search = $model->getFillData()->getSearchable();
		//获取需要展示的字段，列表的表头
		$field = implode(',',array_keys($model->sortable));
		//获取所有的数据
		$data = $respository->finder($field);
		//获取统计数据
		$counter = $respository->counter($field);
		//处理分页参数问题
		$current_page = empty(request()['p']) ? 1 : request()['p'];
		$this->assign([
			'search' => $search,
			'th' => $th,
			'th_count' => count($th),    //表格列数
			'th_raw' => $th_raw,
			'sorted' => $sorted,    //真正可以排序的字段
			'data' => $data['data'],
			'sum_pages' => $data['sumPages'],
			'total' => $data['total'],
			'current_page' => $current_page,
			'per_page' => $data['perPage'],
			'pages' => $data['show'],
			'request' => request(),
			'counter' => $counter
		]);
		if(IS_AJAX){
			return $this->fetch();
		}else{
			$this->display();
		}
	}
	
	/**
	 * 更新快云存储业务页面
	 * @时间: 2016年10月14日 下午2:46:47
	 * @author: duanbin
	 */
	public function update(){
		$model = new CSM();
		$respository = new CSBR($model);
		$id = request()['id'] + 0;
		$entity = $respository->firstOrFalse(['id' => ['eq',$id]]);
		if(!$entity){
			$this->error('没有该业务的相关信息！');
		}
		$this->assign(['entity' => $entity,'state' => $model->searchable['state']['data'],'free_trial' => [1 => '试用',0 => '购买']]);
		$this->display();
	}
	
	/**
	 * 更新快云存储业务信息
	 * @author: Guopeng
	 */
	public function store(){
		$model = new CSM();
		$respository = new CSBR($model);
		//取参数
		$request = request(true);
		$id = $request['id'];
		unset($request['id']);
		$data = $request;
		//更新操作
		$res = $respository->update($data,$id,'id');
		//返回结果
		if($res === false){
			$msg = $model->getError().'更新业务信息失败，请重试！';
			if(IS_AJAX){
				$this->error($msg,'',true);
			}else{
				$this->error($msg);
			}
		}else{
			$msg = '更新业务信息成功';
			$url = U('Cloudstorage/index');
			if(IS_AJAX){
				$this->success($msg,$url,true);
			}else{
				$this->success($msg,$url);
			}
		}
	}
	
	/**
	 * 删除快云存储业务
	 * @时间: 2016年10月17日 下午2:39:35
	 * @author: duanbin
	 */
	public function erase(){
		$model = new CSM();
		$respository = new CSBR($model);
		//取参数
		$request = request();
		$id = $request['id'];
		//删除业务操作
		$res = $respository->eraseCloudstorageBusiness($id);
		//返回结果
		if($res === false){
			$msg = $model->getError();
			if(IS_AJAX){
				$this->error($msg,'',true);
			}else{
				$this->error($msg);
			}
		}else{
			$msg = '删除业务成功';
			if(IS_AJAX){
				$this->success($msg,'',true);
			}else{
				$this->success($msg);
			}
		}
	}
	
	/**
	 * 业务详情页面
	 * @author: Guopeng
	 * @param: variable
	 */
	public function details(){
		$model = new CSM();
		$respository = new CSBR($model);
		//获取业务id
		$id = request()['id'] + 0;
		//获取业务信息
		$entity = $respository->firstOrFalse(['id' => ['eq',$id]]);
		if(!$entity){
			$this->error('参数有误，没有该业务的相关信息！');
			die;
		}
		//获取业务的产品配置相关信息
		$config = (new \Common\Model\ProductConfigModel())->getConfigByPId($entity['product_id']);
		$area_code = (new \Common\Model\RegionModel())->getArea();
		$this->assign([
			'entity' => $entity,
			'free_trial' => [1 => '试用',0 => '购买'],//账户状态
			'model' => [1 => '流量模式',2 => '带宽模式',3 => "切换中"],//账户状态
			'state' => $model->searchable['state']['data'],
			'id' => $id,
			'area_code' => $area_code,
			'config' => $config,
			'ip_state' => [0 => '未绑定',1 => '已绑定未成功',2 => '绑定成功']
		]);
		$this->display();
	}
	
	/**
	 * 转让快云存储业务
	 * @时间: 2016年10月28日 上午11:24:21
	 * @author: duanbin
	 */
	public function assignment(){
		$model = new CSM();
		$respository = new CSBR($model);
		//取参数
		$request = request();
		//转让快云存储操作
		$res = $respository->assignment($request);
		//返回结果
		if($res === false){
			$msg = $model->getError().'请重试！';
			if(IS_AJAX){
				$this->error($msg,'',true);
			}else{
				$this->error($msg);
			}
		}else{
			$msg = '操作成功';
			if(IS_AJAX){
				$this->success($msg,'',true);
			}else{
				$this->success($msg);
			}
		}
	}
	
	/**
	 * 同步快云存储业务
	 * @时间: 2016年10月28日 上午11:24:21
	 * @author: duanbin
	 */
	public function sync(){
		$model = new CSM();
		$respository = new CSBR($model);
		//取参数
		$request = request();
		$id = $request['id'];
		//同步快云存储操作
		//同步方法内部进行了处理，会找到相应的ptype
		$res = $respository->CloudstorageBusinessSynchronizing($id);
		//返回结果
		if($res === false){
			$msg = $model->getError();
			if(IS_AJAX){
				$this->error($msg,'',true);
			}else{
				$this->error($msg);
			}
		}else{
			$msg = '操作成功';
			if(IS_AJAX){
				$this->success($msg,'',true);
			}else{
				$this->success($msg);
			}
		}
	}

	/**
	 * 批量更新同步业务信息
	 * @时间: 2016年11月1日 下午4:51:23
	 * @author: duanbin
	 */
	public function syncBatch(){
		$model = new CSM();
		$respository = new CSBR($model);
		//取参数
		$request = request();
		$flag = $request['flag'];
		$api = $request['atype'];
		//批量同步快云存储操作
		$res = $respository->syncBatch(GD::PTYPE_CLOUD_STORAGE,$flag,"storageywbhlist",$api);
		//返回结果
		if($res === false){
			$msg = $model->getError();
			if(IS_AJAX){
				$this->error($msg,'',true);
			}else{
				$this->error($msg);
			}
		}else{
			$msg = $res;
			if(IS_AJAX){
				$this->success($msg,'',true);
			}else{
				$this->success($msg);
			}
		}
	}
	
	/**
	 * 批量删除
	 * @时间: 2017年1月3日 下午2:50:31
	 * @author: duanbin
	 */
	public function batcherase(){
		$model = new CSM();
		$respository = new CSBR($model);
		//取参数
		$request = request();
		//转让vps操作
		$res = $respository->batchErase($request);
		//返回结果
		if($res === false){
			$msg = $model->getError();
			if(IS_AJAX){
				$this->error($msg,'',true);
			}else{
				$this->error($msg);
			}
		}else{
			$msg = '删除成功';
			if(IS_AJAX){
				$this->success($msg,'',true);
			}else{
				$this->success($msg);
			}
		}
	}

}
