<?php
namespace Backend\Model;

use Backend\Model\BackendModel;
use Common\Aide\AgentAide;
use Common\Aide\ImagesAide;
use Common\Aide\UpdateAide;

/**
 * 产品模型类
 * @author: duanbin
 * @时间: 2016年10月9日 下午3:34:41
 */
class SysModel extends BackendModel{
	//关联的表名
	protected $trueTableName = 'agent_sys';

	//新增是允许写入的字段
	protected $insertFields = ['sys_type','sys_key','sys_value','sys_des'];

	//更新是允许更新的字段
	protected $updateFields = ['sys_type','sys_key','sys_value','sys_des'];
	
	/** 产品类型对应的业务表名 */
	private $product_type_with_business_table_map = [
		'vps' => 'vps_business',
		'host' => 'virtualhost_business',
		'domain' => 'domain_business',
		'hkhost' => 'virtualhost_business',
		'endomain' => 'domain_business',
		'cndomain' => 'domain_business',
		'managehire' => '',
		'cloudspace' => 'cloudspace_business',
		'fastcloudvps' => 'fast_vps_business',
		'dedehost' => 'virtualhost_business',
		'usahost' => 'virtualhost_business',
		'cloudVirtual' => 'virtualhost_business',
		'cloudserver' => 'cloudserver_business',
		'cloudserverIP' => 'cloudserver_business_ip',
		'clouddb' => 'clouddb_business',
		'ssl' => 'ssl_business'
	];
	
	//sys表的sys_type所对应的
	const SYSTEM_CONFIG = 1;			//系统配置
	const BASIC = 1;					//网站的一些基本信息比如地址、名称等
	const CONTACT = 1;					//客服QQ及联系方式设置
	const API = 2;						//API设置
	const PAYMENT = 7;					//支付设置
	const IMG = 1;						//logo与二维码
	const CUSTOM = 9;					//其他设置
	const TOP_BAR = 3;					//整站特殊的网站头部的紧急或特殊活动的公告
	const ABOUT = 4;					//关于我们的介绍页
	const PAYMENT_PAGE = 5;				//其他付款方式页
	const PRODUCT = 8;					//产品设置
	const LOGIN = 6;					//第三方登录
	const DEFAULT_DOMAIN = 10;			//默认域名
	const HOT_SELLING = 11;				//热销商品
	const SEO = 12;						//seo优化关键字的设置
	const MAIL = 13;					//网站邮箱的配置
	const MAIL_BAR = 13;				//邮件模板设置
	const END_BAR = 15;					//网站底部自由代码
	private $system_config = [];
	
	/**
	 * 初始化的时候  将网站的默认配置项加载进来
	 * @时间: 2016年11月13日 下午3:53:51
	 * @author: duanbin
	 */
	protected function _initialize(){
		parent::_initialize();
		$this->system_config = WebSiteConfig(self::SYSTEM_CONFIG);
	}

	/**********************************新增更新回调/开始***********************************/
	/**
	 * 插入数据之前的回调
	 * @时间: 2016年10月17日 上午11:28:21
	 * @author: duanbin
	 * @param $data
	 * @param $options
	 * @return bool
	 */
	protected function _before_insert(&$data,$options){
		//处理问题内容的编码，统一转换成utf-8的编码，然后查看字数
		$sys_value = mb_convert_encoding($data['sys_value'], 'utf-8');
		if ( mb_strlen($sys_value, 'utf-8') >= 10000*3) {
			$this->error = '内容最多只有10000个字';
			return false;
		}
	}

	/**
	 * 插入成功后的回调
	 * @时间: 2016年10月17日 上午11:28:50
	 * @author: duanbin
	 * @param $data
	 * @param $options
	 */
	protected function _after_insert($data,$options){}
	
	/**
	 * 更新数据之前做的操作
	 * @时间: 2016年10月17日 上午11:26:36
	 * @author: duanbin
	 * @param $data
	 * @param $options
	 * @return bool
	 */
	protected function _before_update(&$data, $options){
		//处理问题内容的编码，统一转换成utf-8的编码，然后查看字数
		$sys_value = mb_convert_encoding($data['sys_value'],'utf-8');
		if ( mb_strlen($sys_value, 'utf-8') >= 10000*3) {
			$this->error = '内容最多只有10000个字';
			return false;								
		}
	}

	/**
	 * 更新之后做的操作
	 * @时间: 2016年10月17日 上午11:27:09
	 * @author: duanbin
	 * @param $data
	 * @param $options
	 */
	protected function _after_update($data,$options){}
	/**********************************新增更新回调/结束***********************************/

	/**
	 * 更新sys表的核心方法
	 * @时间: 2016年11月11日 下午5:28:53
	 * @author: duanbin
	 * @param $data
	 * @param $type
	 * @return bool
	 */
	protected function process($data,$type){
		$error = 0;
		$ok = 0;
		foreach($data as $k => $v){
			$where['sys_key'] = ['eq',$k];
			$where['sys_type'] = ['eq',$type];
			//这里只修改有变动的
			if($v !== $this->system_config[$k]){
				$res = $this->where($where)->setField('sys_value',clearXSS($v));
				$res === false ? $error++ : $ok++;
			}
		}
		if(!$error){
			return true;
		}else{
			$this->error = '哎呦，出现了一些差错，在试一次吧！';
			return false;
		}
	}
	
	/**
	 * 更新网站配置的方法
	 * @时间: 2016年11月11日 下午4:59:59
	 * @author: duanbin
	 * @param $data
	 * @return bool
	 */
	public function setup($data) {
		//拿到表单
		$form = strtolower($data['form']);
		unset($data['form']);
		switch ($form){
			case 'basic': //网站基本设置
				$type = self::BASIC;
				break;
			case 'contact': //客服
				$type = self::CONTACT;
				break;
			case 'api': //API设置
				$type = self::API;
				if(!isset($data['pay_hk'])){
					unset($data['pay_hk']);
				}
				break;
			case 'payment': //支付设置
				$type = self::PAYMENT;
				if(!isset($data['pay_sft'])){
					unset($data['pay_sft']);
				}
				if(!isset($data['pay_cft'])){
					unset($data['pay_cft']);
				}
				if(!isset($data['pay_zfb'])){
					unset($data['pay_zfb']);
				}
				break;
			case 'img': //如果是修改logo或者是二维码
				$type = self::IMG;
				//处理pc端logo图片
				$pc = 'logo_url';
				if(isset($_FILES[$pc]) && $_FILES[$pc]['error'] == 0){
					$path_pc = $this->imgHandler($pc);
					if(!$path_pc){
						return false;
					}else{
						$data['logo_url'] = $path_pc;
					}
				}
				//处理手机端logo图片
				$phone = 'm_logo_url';
				if(isset($_FILES[$phone]) && $_FILES[$phone]['error'] == 0){
					$path_m = $this->imgHandler($phone);
					if(!$path_m){
						return false;
					}else{
						$data['m_logo_url'] = $path_m;
					}
				}
				//处理二维码
				if(!empty($data['qr_url'])){
					//文本信息不为空时，创建二维码图片
					$qr['text'] = $data['qr_url'];//二维码中保存的信息
					$qr['save_name'] = 'QRCode.png';//二维码图片的名称
					if(!empty($data['logo_url'])){
						$qr['logo_url'] = '.'.$data['logo_url'];
					}else{
						$qr['logo_url'] = file_exists('.'.$this->system_config['logo_url']) ? '.'.$this->system_config['logo_url'] : '';//二维码中要展示的logo图片；
					}
					$qr['label_text'] = '';        //二维码中的提示语
					$path = $this->imgHandler($qr,true);
					if(!$path){
						return false;
					}else{
						$data['qr_url'] = $path;
					}
				}else{
					unset($data['qr_url']);
				}
				break;
			case 'product':
				$type = self::PRODUCT;
				if(isset($data['site_trial_times'])){
					if(($data['site_trial_times'] + 0) <= 0){
						$this->error = '试用次数必须大于0的数组！';
						return false;
					}
				}
				if(isset($data['site_buy_vps'])){
					if(!in_array($data['site_buy_vps'] + 0,array(0,1,2,3,4))){
						$data['site_buy_vps'] = 0;
					}
				}
				if(isset($data['site_buy_cloud'])){
					if($data['site_buy_cloud'] === "0" || $data['site_buy_cloud'] === 0){
						$data['site_buy_cloud'] = 0;
					}elseif($data['site_buy_cloud'] + 0 > 0){
						$data['site_buy_cloud'] = ceil($data['site_buy_cloud'] + 0);
					}else{
						$data['site_buy_cloud'] = -1;
					}
				}
				break;
			case 'custom': //其他设置
				$type = self::CUSTOM;
				break;
			case 'topbar': //顶部活动或紧急通知的处理，特殊一点
				$type = self::TOP_BAR;
				$where['sys_type'] = ['eq',$type];
				//交换数据
				list($temp,$data) = [$data,[]];
				$data['sys_key'] = $temp['is_show'] + 0;
				$data['sys_value'] = $_POST['topbar'];
				$res = $this->where($where)->save($data);
				if($res === false){
					$this->error = '哎呦，出现了一些差错，在试一次吧！';
					return false;
				}else{
					return true;
				}
				break;
			case 'about':
				$type = self::ABOUT;
				$data['on_the_title'] = $_POST['on_the_title'];
				$data['on_the_content'] = $_POST['on_the_content'];
				break;
			case 'payment_page':
				$type = self::PAYMENT_PAGE;
				$data['payment_content'] = $_POST['payment_content'];
				break;
			case 'login': //第三方登录
				$type = self::LOGIN;
				if(!isset($data['login_qq'])){
					unset($data['login_qq']);
				}
				break;
			case 'domain':
				$type = self::DEFAULT_DOMAIN;
				//交换数据
				list($temp,$data) = [$data,[]];
				$data['default_domain'] = implode(',',array_merge($temp['others_domain'],$temp['chinese_domain']));
				break;
			case 'seo':
				$type = self::SEO;
				//交换数据
				list($temp,$data) = [$data,[]];
				//拼凑要修改的数据
				//去除用户输入的英文 " ! "
				array_walk($temp,function (&$v,$k){
					$v = str_replace('!','',$v);
				});
				$data[$temp['sys_key']] = implode('!',[$temp['keywords'],$temp['description'],$temp['title']]);
				break;
			case 'mail':
				$type = self::MAIL;
				if(!isset($data['mailaddcc'])){
					$data['mailaddcc'] = "";
				}
				if(!isset($data['mailsender'])){
					$data['mailsender'] = "";
				}
				break;
			case 'mailbar':
				//邮件内容的处理，特殊一点
				$type = self::MAIL_BAR;
				$where['sys_type'] = ['eq',$type];
				$where['sys_key'] = ["eq","mail_content"];
				//交换数据
				list($temp,$data) = [$data,[]];
				$data['sys_value'] = json_encode($temp);
				$res = $this->where($where)->save($data);
				if($res === false){
					$this->error = '哎呦，出现了一些差错，在试一次吧！';
					return false;
				}else{
					return true;
				}
				break;
			case 'endbar':
				//底部自由代码的处理，特殊一点
				$type = self::END_BAR;
				$where['sys_type'] = ['eq',$type];
				//交换数据
				list($temp,$data) = [$data,[]];
				$data['sys_key'] = $temp['is_show'] + 0;
				$data['sys_value'] = $_POST['endbar'];
				$res = $this->where($where)->save($data);
				if($res === false){
					$this->error = '哎呦，出现了一些差错，在试一次吧！';
					return false;
				}else{
					return true;
				}
				break;
		}
		return $this->process($data,$type);
	}

	/**
	 * 用于网站的设置的图片和二维码的处理
	 * @时间: 2016年11月11日 下午6:16:04
	 * @author duanbin
	 * @param: $input_name 二维码是要传入个数组，keys---text,save_name,logo_url,label_text;
	 * @param bool $is_QR
	 * @return bool|string
	 */
	protected function imgHandler($input_name, $is_QR = false){
		$img_aide = new ImagesAide();
		//生成二维码
		if($is_QR){
			try{
				$path = $img_aide->QRCoderPainter($input_name['text'],$input_name['save_name'],$input_name['logo_url'],$input_name['label_text']);
			}catch(\Exception $e){
				$this->error = $e->getMessage();
				return false;
			}
			return $path;
		}else{
			//普通的图片上传
			$res_info = $img_aide->ImgUploader($input_name,'ad');
			//上传失败，返回错误信息
			if(!$res_info['ok']){
				$this->error = $res_info['error'];
				return false;
			}else{
				//上传图片成功，那么就保存图片路径到数据库
				return $res_info['file'][0];
			}
		}
	}
	
	/**
	 * 获取临近$days的所有业务
	 * @时间: 2016年11月24日 上午11:33:55
	 * @author: duanbin
	 * @return mixed
	 */
	public function getIndexRecentBusiness(){
		$db_prefix = C('DB_PREFIX');
		$a = 'a'; $b = 'b'; $c = 'c';
		$product_join = 'left join '.$db_prefix.'product as '.$b.' on '.$a.'.product_id = b.id';
		$member_join = 'left join '.$db_prefix.'member as '.$c.' on '.$a.'.user_id = c.user_id';
		$where['_string'] = ' overdue_time between now() and date_add(now(), INTERVAL 1 MONTH) and '.$a.'.user_id != -1';
		$host_field = $a.'.overdue_time,'.$a.'.id,'.$c.'.login_name,'.$b.'.product_name,'.$a.'.create_time,'.$a.'.domain_name as name,'.$b.'.product_type_id';
		$res['virtualhost_business'] = M('virtualhost_business')->alias($a)->field($host_field)->join($product_join)->join($member_join)->where($where)->select();
		$vps_field = $a.'.overdue_time,'.$a.'.id,'.$c.'.login_name,'.$b.'.product_name,'.$a.'.create_time,'.$a.'.ip_address as name,'.$b.'.product_type_id';
		$res['vps_business'] = M('vps_business')->alias($a)->field($vps_field)->join($product_join)->join($member_join)->where($where)->select();
		$res['fast_vps_business'] = M('fast_vps_business')->alias($a)->field($vps_field)->join($product_join)->join($member_join)->where($where)->select();
		$cloudserver_field = $a.'.overdue_time,'.$a.'.id,'.$c.'.login_name,'.$b.'.product_name,'.$a.'.create_time,'.$a.'.api_bid,'.$a.'.nw_ip as name,'.$b.'.product_type_id';
		$res['cloudserver_business'] = M('cloudserver_business')->alias($a)->field($cloudserver_field)->join($product_join)->join($member_join)->where($where)->select();
		$domain_field = $a.'.overdue_time,'.$a.'.id,'.$c.'.login_name,'.$b.'.product_name,'.$a.'.create_time,'.$a.'.domain_name as name,'.$b.'.product_type_id';
		$res['domain_business'] = M('domain_business')->alias($a)->field($domain_field)->join($product_join)->join($member_join)->where($where)->select();
		$cloudspace_field = $a.'.overdue_time,'.$a.'.id,'.$c.'.login_name,'.$b.'.product_name,'.$a.'.create_time,'.$a.'.ip_address as name,'.$b.'.product_type_id';
		$res['cloudspace_business'] = M('cloudspace_business')->alias($a)->field($cloudspace_field)->join($product_join)->join($member_join)->where($where)->select();
//		$cloudserver_ip_field = $a.'.overdue_time,'.$a.'.id,'.$c.'.login_name,'.$b.'.product_name,'.$a.'.create_time,'.$a.'.ipaddress,'.$b.'.product_type_id';
//		$res['cloudserver_business_ip'] = M('cloudserver_business_ip')->alias($a)->field($cloudserver_ip_field)->join($product_join)->join($member_join)->where($where)->select();
//		$return['CloudserverIp'] = $res['cloudserver_business_ip'];
		$return['Virtualhost'] = $res['virtualhost_business'];
		$return['FastVps'] = $res['fast_vps_business'];
		$return['Vps'] = $res['vps_business'];
		$return['Cloudserver'] = $res['cloudserver_business'];
		$return['Cloudspace'] = $res['cloudspace_business'];
		$return['domain'] = $res['domain_business'];
		return $return;
	}
	
	/**
	 * 发送即将到期业务提醒邮件
	 * @时间: 2016年11月24日 下午2:16:42
	 * @author: duanbin
	 * @return bool
	 */
	public function sendMails(){
		$request = request();
		$ids = explode(',', $request['ids']);
		$m_product_type = M('product_type');
		$m_member = M('member');
		$db_prefix = C('DB_PREFIX');
		$this->error = '';
		$ok = $err = 0 ;
		//处理相关参数
		foreach ($ids as $k => $v){
			if (empty($v)){
				$this->error .= '参数错误<br/>';
				$err++;
				continue;
			}
			list($type_id, $business_id) = explode('-', $v);
			$type_id = $type_id+0;
			//如果参数为空略过
			if (empty($type_id) || empty($business_id)){
				$this->error .= '参数错误<br/>';
				$err++;
				continue;
			}
			//获取业务的api_ptype
			$type_name = $this->gussePtype($type_id, $m_product_type);
			if(empty($type_name)){
				$this->error .= '业务标识['.$business_id.']的业务类型错误，发送邮件失败<br/>';
				$err++;
				continue;
			}
			//获取业务ptype
			$ptype = $type_name;
			$business_name = $this->product_type_with_business_table_map[$type_name];
			if(empty($business_name)){
				$this->error .= '业务标识['.$business_id.']的业务类型错误，发送邮件失败<br/>';
				$err++;
				continue;
			}
			//先同步业务
			$business_sync = $this->syncBusiness($type_id,$ptype,$business_id);
			if(!$business_sync){
				$this->error .= '业务标识['.$business_id.']的业务同步失败，发送邮件失败<br/>';
				$err++;
				continue;
			}
			//获取业务信息
			$where['a.id'] = ['eq',$business_id];
			$business_info = M($business_name)->alias('a')->field('a.*,b.product_name as business_name,b.product_type_id')
			->join('left join '.$db_prefix.'product as b on a.product_id = b.id')->where($where)->find();
			//如果没有响应的业务信息
			if (empty($business_info)){
				$this->error .= '业务标识['.$business_id.']的业务信息不存在，发送邮件失败<br/>';
				$err++;
				continue;
			}
			//判断查询出来的时间是否临近30天到期
			$overdue_time = strtotime($business_info['overdue_time']);
			$new = strtotime('+1 month');
			if($overdue_time < $new){
				//获取会员信息
				$member_info = $m_member->where(['user_id'=>['eq',$business_info['user_id']]])->find();
				if (empty($member_info)){
					$this->error .= '业务标识['.$business_id.']的会员信息不存在，发送邮件失败<br/>';
					$err++;
					continue;
				}
				//如果该会员没有邮箱
				if (empty($member_info['user_mail'])){
					$this->error .= '业务标识['.$business_id.']的会员邮箱不存在，发送邮件失败<br/>';
					$err++;
					continue;
				}
				//组装邮件内容
				$mail_content = HTMLContentForEmail(1,$business_info,$member_info);
				//发送邮件
				$res = postOffice($member_info['user_mail'], $mail_content['subject'],$mail_content['body'],1);
				$res["status"] == 1 ? $err++: $ok++;
			}else {
				$this->error .= '业务标识['.$business_id.']的业务未过期，不发送邮件<br/>';
				$err++;
			}
		}
		$this->error .= '共发送成功'.$ok.'封邮件，共发送失败'.$err.'封邮件<br/>';
		return true;
	}
	
	/**
	 * 通过产品类型名称得到表名
	 * @时间: 2016年11月24日 下午3:04:20
	 * @author: duanbin
	 * @param $type_id
	 * @param null $m_product_type
	 * @return mixed
	 */
    protected function gusseTableName($type_id, $m_product_type = null){
        if ($m_product_type == null){
            $m_product_type = M('product_type');
        }
        $type_name = $m_product_type->field('api_ptype')->where([ 'id' => [ 'eq', $type_id ] ])->find();
        $type_name = $type_name['api_ptype'];
        return $this->product_type_with_business_table_map[$type_name];
    }
	
	/**
	 * 通过产品类型名称得到表名
	 * @时间: 2016年11月24日 下午3:04:20
	 * @author: duanbin
	 * @param $type_id
	 * @param null $m_product_type
	 * @return mixed|string
	 */
	protected function gussePtype($type_id, $m_product_type = null){
        if ($m_product_type == null){
            $m_product_type = M('product_type');
        }
        $type_name = $m_product_type->field('api_ptype')->where(['id'=>['eq',$type_id]])->find();
        if(empty($type_name)){
            $type_name = "";
        }else{
            $type_name = $type_name['api_ptype'];
        }
        return $type_name;
	}
	
	/**
	 * 同步业务信息
	 * @时间: 2016年11月24日 下午3:04:20
	 * @author: duanbin
	 * @param $type_id
	 * @param $ptype
	 * @param $business_id
	 * @return bool
	 */
	protected function syncBusiness($type_id,$ptype,$business_id){
	   if($type_id == 7 || $type_id == 8 || $type_id == 15 || $type_id == 16 || $type_id == 17){
	       //虚拟主机
	       $where['id'] = ["eq",$business_id];
	       $vhost = new VirtualhostModel();
	       $business_info = $vhost->where($where)->find();
	       $vhostRespository = new \Common\Respository\VirtualhostBusinessRespository($vhost);
	       $result = $vhostRespository->VirtualhostBusinessSynchronizing($business_info['business_id'],$ptype);
	   }elseif ($type_id == 1){
	       //VPS
		   $where['id'] = ["eq",$business_id];
		   $vps = new VpsModel();
		   $business_info = $vps->where($where)->find();
	       $vpsRespository = new \Common\Respository\VpsBusinessRespository($vps);
	       $result = $vpsRespository->VpsBusinessSynchronizing($business_info['business_id'],$ptype);
	   }elseif ( $type_id == 13){
	       //快云VPS
		   $where['id'] = ["eq",$business_id];
	       $fastvps = new FastVpsModel();
           $business_info = $fastvps->where($where)->find();
	       $fastvpsRespository = new \Common\Respository\VpsBusinessRespository($fastvps);
	       $result = $fastvpsRespository->VpsBusinessSynchronizing($business_info['business_id'],$ptype);
	   }elseif($type_id == 12){
	       //云空间
		   $where['id'] = ["eq",$business_id];
	       $cloudspace = new CloudspaceModel();
           $business_info = $cloudspace->where($where)->find();
	       $cloudspaceRespository = new \Common\Respository\CloudspaceBusinessRespository($cloudspace);
	       $result = $cloudspaceRespository->CloudspaceBusinessSynchronizing($business_info['business_id']);
       }elseif($type_id == 9 || $type_id == 10){
           //域名
           $where['id'] = ["eq",$business_id];
           $domain = new DomainModel();
           $business_info = $domain->where($where)->find();
           $domainRespository = new \Common\Respository\DomainRespository($domain);
           $result = $domainRespository->DomainBusinessSynchronizing($business_info['api_bid']);
	   }elseif($type_id == 18){
	       //快云服务器
		   $where['id'] = ["eq",$business_id];
	       $cloudserver = new CloudserverModel();
           $business_info = $cloudserver->where($where)->find();
	       $cloudserverRespository = new \Common\Respository\CloudserverBusinessRespository($cloudserver);
	       $result = $cloudserverRespository->CloudserverBusinessSynchronizing($business_info['api_bid']);
	   }elseif($type_id == 20){
           //ssl
		   $where['id'] = ["eq",$business_id];
           $ssl = new SslModel();
           $business_info = $ssl->where($where)->find();
           $sslRespository = new \Common\Respository\SslRespository($ssl);
           $result = $sslRespository->SslBusinessSynchronizing($business_info['business_id']);
       }elseif($type_id == 22){
           //快云数据库
		   $where['id'] = ["eq",$business_id];
           $clouddb = new ClouddbModel();
           $business_info = $clouddb->where($where)->find();
           $clouddbRespository = new \Common\Respository\ClouddbBusinessRespository($clouddb);
           $result = $clouddbRespository->ClouddbBusinessSynchronizing($business_info['api_bid']);
       }else{
           $result = false;
       }
	   if($result){
	       return true;
	   }else{
	       return false;
	   }
	}
	
	/**
	 * 测试通信接口
	 * @时间: 2016年11月25日 上午10:24:49
	 * @author: duanbin
	 * @return bool
	 */
	public function testCommunication(){
		$atype = request()["atype"];
		$area_code = 4001;
        $api_config = WebSiteConfig(2);//获取网站配置
        $api_access = $api_config["api_access"]+0;
        $api_access = $api_access ? $api_access : 1;
		if($atype == "hk"){
			if($api_config["api_hk"] != 1){
				$this->error = '国际站API配置未开启！请在：网站后台->网站设置->网站基本设置->API设置，开启您的国际站API配置。';
				return false;
			}
			$api_access = $api_config["api_hk_access"]+0;
			$api_access = $api_access ? $api_access : 6;
			$area_code = 4002;
		}
		$ptype = "cloudserver";
		$pname = "cloudserver.getKVMsystem";
		$tid = 56;
		$agent = new AgentAide(1,$api_access);
		$transaction = $agent->servant;
		try{
			$result = $transaction->GetOsType($ptype,$pname,$tid,$area_code);
			api_log(-1,"测试通信",$result,"通信成功-access:".$api_access);
		}catch(\Exception $e){
			api_log(-1,"测试通信",$e->getMessage(),"通信失败-access:".$api_access);
			$this->error = '接口调用失败';
			return false;
		}
		$xstr = json_decode($result,true);
		if($xstr == null){
			$message = "通信失败，接口暂时无法使用。";
			$this->error = $message;
			return false;
		}
		$code = $xstr["code"];
		$message = "通信失败，平台无法正常交易，请在系统设置里查看你的网站信息是否正确。";
		switch ($code){
			case 0: $message="可以正常通信";break;
			case 99: $message="通信失败，接口繁忙。";break;
			case 110: $message="通信失败，已经被取消调用接口的资格。";break;
			case 1001: $message="通信失败，签名验证错误。";break;
			case 1002: $message="通信失败，客户端请求超时，请更新您的服务器时间。";break;
			case 1005: $message="通信失败，Access Id错误，请在：网站后台->网站设置->网站基本设置->API设置，设置您的API信息。";break;
			case 1006: $message="通信失败，调用IP错误，请在：景安站国际站-管理中心-服务支持-API设置，取消您的调用IP限制。";break;
			case 3004: $message="通信失败，没有找到该代理会员。";break;
		}
		$this->error = $message;
		return false;
	}
	
	/**
	 * 一键备份
	 * @时间: 2016年11月25日 上午11:52:28
	 * @author: duanbin
	 * @return bool
	 */
	public function oneTouchBackup(){
		$updater = new UpdateAide();
		//备份数据
		$updater->mysql_backup_hander->setPath(C('BACKUP_PATH').'UserBackup');
		$res['data'] = $updater->mysql_backup_hander->backup();
		//备份文件
		$res['software'] = $updater->Softwarebak(true,'UserBackup');
		if($res['data'] && $res['software']){
			return true;
		}else{
			$this->error = !$res['data'] ? $updater->mysql_backup_hander->error() : $updater->info;
			return false;
		}
	}

	/**
	* 测试邮件发送
	* @date: 2017年1月11日 上午11:14:57
	* @author: Lyubo
	 * @param $data
	 * @return array
	 */
	public function mailtest($data){
	    $mail = $data['test'];
	    $content = HTMLContentForEmail(8,'','');
	    return postOffice($mail,$content['subject'],$content['body'],8);
	}

	/**
	 * 添加新API配置
	 * @date: 2018年3月5日11:17:17
	 * @author: Guopeng
	 * @param $data
	 * @return bool
	 */
	public function add_api($data){
		$code = $data["code"];
		$num = $data["num"] + 0;
		if($code == "com"){
			if($num > 5){
				$this->error = "最多添加5个国内API！";
				return false;
			}
			$code = "";
			$type = "国内站";
		}elseif($code == "hk"){
			if($num > 10){
				$this->error = "最多添加5个国际API！";
				return false;
			}
			$code = "hk_";
			$type = "国际站";
		}else{
			$this->error = "添加API失败！";
			return false;
		}
		$access_id = "api_access_id".$num;
		$access_key = "api_access_key".$num;
		$api_config = WebSiteConfig(self::API);//获取api配置
		if(isset($api_config[$access_id])){
			if(isset($api_config[$access_key])){
				return true;
			}else{
				$inside[] = ["sys_type"=>self::API,"sys_key"=>$access_key,"sys_value"=>"access_key","sys_des"=>"{$code}access_key".$num];
			}
		}else{
			if(isset($api_config[$access_key])){
				$inside[] = ["sys_type"=>self::API,"sys_key"=>$access_id,"sys_value"=>"access_id","sys_des"=>"{$code}access_id".$num];
			}else{
				$inside[] = ["sys_type"=>self::API,"sys_key"=>$access_id,"sys_value"=>"access_id","sys_des"=>"{$code}access_id".$num];
				$inside[] = ["sys_type"=>self::API,"sys_key"=>$access_key,"sys_value"=>"access_key","sys_des"=>"{$code}access_key".$num];
			}
		}
		$res = $this->addAll($inside);
		if($res !== false){
			$this->where(["sys_type"=>self::API,"sys_key"=>"api_{$code}access_num"])->setInc("sys_value");
			return true;
		}else{
			$this->error = "添加{$type}API失败！";
			return false;
		}
	}

	/**
	 * 删除API配置
	 * @date: 2018年3月5日11:17:17
	 * @author: Guopeng
	 * @param $data
	 * @return bool
	 */
	public function del_api($data){
		$num = $data["num"] + 0;
		if($num < 1 || $num > 10){
			$this->error = "该API配置不存在，删除API失败！";
			return false;
		}
		$access_id = "api_access_id".$num;
		$access_key = "api_access_key".$num;
		$where["sys_type"] = self::API;
		$where['_string'] = "sys_key = '".$access_id."' OR sys_key = '".$access_key."'";
		$res = $this->where($where)->delete();
		if($res !== false){
			if($num < 6){
				$this->where(["sys_type"=>self::API,"sys_key"=>"api_access_num"])->setDec("sys_value");
			}else{
				$this->where(["sys_type"=>self::API,"sys_key"=>"api_hk_access_num"])->setDec("sys_value");
			}
			return true;
		}else{
			$this->error = "删除API失败！";
			return false;
		}
	}
}
