<?php
namespace Backend\Model;
use Backend\Model\BackendModel;
use Common\Model\RegionModel;

/**
 * 会员模型类
 * @author: duanbin
 * @时间: 2016年10月9日 下午3:34:41
 */
class UserLevelModel extends BackendModel{
	//关联的表名
	protected $trueTableName = 'agent_user_level';

	/**
	 * 获取会员级别产品折扣信息
	 * @时间: 2017年11月27日11:12:22
	 * @author: Guopeng
	 */
	public function get_product_discount(){
		$product_type = new ProductTypeModel();
		$product_type_ids = "7,8,12,15,16,17,1,13,14,9,10,18,22,20";
		$product = $product_type->where(["id"=>["in",$product_type_ids]])->select();
		foreach($product as $k=>$v){
			$product[$k]["discount"] = $this->alias('l')->where(["product_type_id"=>$v["id"]])->order("r.region_code")
				->join("left join agent_region as r on l.region_id = r.id")->select();
		}
		return $product;
	}

	/**
	 * 添加会员级别折扣
	 * @时间: 2017年11月27日11:12:22
	 * @author: Guopeng
	 */
	public function add_level(){
		$request = request(true);
		$region = new RegionModel();
		$region_where1["state"] = 2;
		$region_where1["region_code"] = $request["region_code"];
		$info = $region->where($region_where1)->select();
		if(!empty($info)){
			$this->setError("该会员级别已存在！");
			return false;
		}
		$region_where2["state"] = 2;
		$region_where2["region_name"] = $request["region_name"];
		$info = $region->where($region_where2)->select();
		if(!empty($info)){
			$this->setError("级别名称重复！");
			return false;
		}
		$data["region_name"] = $request["region_name"];
		$data["region_code"] = $request["region_code"];
		$data["state"] = 2;
		$res = $region->add($data);
		if($res === false){
			$this->setError("添加失败！");
			return false;
		}
		$region_id = $region->getLastInsID();
		$product_type_ids = [7,8,12,15,16,17,1,13,14,9,10,18,22,20,23];
		foreach($product_type_ids as $pid){
			$level_data["region_id"] = $region_id;
			$level_data["product_type_id"] = $pid;
			$level_data["discount"] = 1;
			$res = $this->add($level_data);
		}
		if($res === false){
			$region->where(["id"=>$region_id])->delete();
			$this->setError("添加失败！");
			return false;
		}
		return true;
	}

	/**
	 * 修改会员级别信息
	 * @时间: 2017年11月27日11:12:22
	 * @author: Guopeng
	 */
	public function edit_level(){
		$request = request(true);
		$region = new RegionModel();
		$region_where1["state"] = 2;
		$region_where1["id"] = ["neq",$request['id']];
		$region_where1["region_code"] = $request["region_code"];
		$info = $region->where($region_where1)->select();
		if(!empty($info)){
			$this->setError("该会员级别已存在！");
			return false;
		}
		$region_where2["state"] = 2;
		$region_where2["id"] = ["neq",$request['id']];
		$region_where2["region_name"] = $request["region_name"];
		$info = $region->where($region_where2)->select();
		if(!empty($info)){
			$this->setError("级别名称重复！");
			return false;
		}
		$data["region_name"] = $request["region_name"];
		$data["region_code"] = $request["region_code"];
		$data["state"] = 2;
		$where["id"] = $request['id'];
		$res = $region->where($where)->save($data);
		if($res === false){
			$this->setError("修改失败！");
			return false;
		}
		return true;
	}

	/**
	 * 删除会员级别折扣
	 * @时间: 2017年11月27日11:12:22
	 * @author: Guopeng
	 */
	public function delete_level(){
		$request = request(true);
		$region = new RegionModel();
		$where["id"] = $request['id'];
		$res = $region->where($where)->delete();
		if($res === false){
			$this->setError("删除失败！");
			return false;
		}
		$level_where["region_id"] = $request['id'];
		$res = $this->where($level_where)->delete();
		if($res === false){
			$this->setError("删除失败！");
			return false;
		}
		return true;
	}

	/**
	 * 修改会员级别产品折扣
	 * @时间: 2017年11月27日11:12:22
	 * @author: Guopeng
	 */
	public function update_p_discount(){
		$request = request(true);
		$res = false;
		foreach($request["product_discount"] as $key=>$val){
			$where["region_id"] = $key;
			foreach($val as $k=>$v){
				if($v < 0.1)$v=0.1;
				$where["product_type_id"] = $k;
				$data["discount"] = $v;
				$res = $this->where($where)->save($data);
			}
		}
		if($res === false){
			$this->setError("修改失败！");
			return false;
		}
		return true;
	}
}
