<?php
/**
 * Created by PhpStorm.
 * User: 123456
 * Date: 2017/1/18
 * Time: 17:25
 */
namespace Common\Respository;

use Common\Respository\BusinessRespository;
use Common\Data\GiantAPIParamsData as GD;

class CloudstorageBusinessRespository extends BusinessRespository{

    /**
     * 扩充查询字段，在连表的情况下有别名使用
     * @author: guopeng
     * @param $fields
     * @return array
     */
    protected function fieldsExtra($fields){
        if(is_string($fields)){
            $fields = explode(',',$fields);
        }
        foreach($fields as $k => $filed){
            if($filed == 'product_name'){
                $fields[$k] = 'b.'.$filed;
            }elseif($filed == 'login_name'){
                $fields[$k] = 'c.'.$filed;
            }else{
                $fields[$k] = $this->alias.'.'.$filed;
            }
        }
        return $fields;
    }

    /**
     * 返回一个join数组
     * 连表查询时，请实现此方法
     * @author: Guopeng
     * @return array
     */
    protected function joinsExtra(){
        return ['left join '.$this->table_prefix.'product as b on '.$this->alias.'.product_id = b.id','left join '.$this->table_prefix.'member as c on '.$this->alias.'.user_id = c.user_id',];
    }

    /**
     * 额外的扩充条件，这里要增加一项
     * product_id值得条件
     * @author: Guopeng
     * @param $where
     * @param $request
     * @return array
     */
    protected function whereExtra($where,$request){
        $_where = [];
        foreach($where as $k => $v){
            if($k == 'product_name'){
                $_where['b.product_name'] = $v;
            }elseif($k == 'login_name'){
                $_where['c.login_name'] = $v;
            }else{
                $_where[$this->alias.'.'.$k] = $v;
            }
        }
        return $_where;
    }

    /**
     * 业务统计方法，统计出各个分类的总数等
     * @author: Guopeng=
     * @param $field
     * @return array
     */
    public function counter($field){
        $counter = [];
        /** 总记录数 */
        $counter['total'] = $this->queryBuilder($field,[]);
        /** 成功业务 */
        $where['a.state'] = ['eq',1];
        $counter['successful'] = $this->queryBuilder($field,$where);
        /** 已删除业务 */
        $where['a.state'] = ['eq',2];
        $counter['deleted'] = $this->queryBuilder($field,$where);
        /** 已过期业务 */
        $where['a.state'] = ['eq',3];
        $counter['expired'] = $this->queryBuilder($field,$where);
        /** 失败业务 */
        $where['a.state'] = ['eq',4];
        $counter['failed'] = $this->queryBuilder($field,$where);
        return $counter;
    }

    /**
     * 同步对象存储的业务逻辑
     * @author: Guopeng
     * @param $business_info
     * @param string $attr
     * @return bool
     */
    public function CloudstorageBusinessSynchronizing($business_info,$attr = 'api_bid',$access = 0){
        $business_info_exists = "";
        //如果你传入的是id值那么就获取信息，如果你传入的是一条业务记录(数组),那么就不用再去取了
        if(is_numeric($business_info) && !is_array($business_info)){
            //先获取本地业务信息
            $business_info_exists = $this->model()->where([$attr => ['eq',$business_info]])->find();
            //如果不存在这条记录，那么就写进去
            if(empty($business_info_exists)){
                $api_config = WebSiteConfig(2);//获取网站配置
                $api_access = $api_config["api_access"] + 0;
                $api_access = $access ? $access : ($api_access ? $api_access : 1);
                list($business_info,$temp) = [[],$business_info];
                $business_info['access'] = $api_access;
                $business_info[$attr] = $temp;
                $business_info['user_id'] = -1;
                $business_info['product_name'] = '未同步业务';
                $business_info['create_time'] = current_date();
                $add_id = $this->model()->add($business_info);
                $business_info['id'] = $add_id;
            }else{
                $business_info = $business_info_exists;
            }
        }
        $api_access = $business_info["access"] + 0;
        $api_access = $api_access ? $api_access : 1;
        $business_info['business_id'] = $business_info[$attr];
        $id = $business_info['id'];
        //调用api同步业务信息
        $result = $this->syncBusinessFromZZIDC($business_info,GD::PTYPE_CLOUD_STORAGE);
        if(is_array($result) && !empty($result['json'])){
            //说明通用的单次同步业务逻辑未出错
            $bus_info = $result['json'];
			//业务状态，1：试用，2：正常，3：过期，4：删除
			if($bus_info['ywzt'] == 1 || $bus_info['ywzt'] == 2){
				$state = 1;
			}elseif($bus_info['ywzt'] == 3){
				$state = 3;
			}elseif($bus_info['ywzt'] == 4){
				$state = 2;
			}else{
				$state = 4;
			}
            // 业务信息
            $parms['open_time'] = $bus_info['ktsj']; // 开通时间
			$parms['overdue_time'] = $bus_info['endtime']; // 到期时间
			$parms['ywbs'] = $bus_info['storagebs'];//业务标识
			$parms['free_trial'] = $bus_info['ywzt'] == 1 ? 1 : 0;//试用/购买
			$parms['model'] = $bus_info['model'];//模式：1为流量模式，2为带宽模式，3为切换中
			$parms['ywlx'] = $bus_info['ywlx'];//业务类型，0：老业务，1：新业务
			$parms['api_bid'] = $bus_info['ywbh'];//业务编号
			$parms['state'] = $state;//业务状态，1：成功,2：已删除,3：已过期,4：失败
			$parms['dk_overdue_time'] = $bus_info['dkendtime'];//带宽到期时间
            $parms['syqx'] = $bus_info['remainQuotaTime'];//业务剩余期限
			//$parms['dkbh'] = $bus_info['dkbh'];//带宽编号
            $parms['dk_time'] = $bus_info['remainBandTime'];//带宽剩余期限
			$parms['dk_dqzt'] = $bus_info['dkIsdq'];//带宽是否到期；0：未到期，1：已到期
			$parms['dk'] = $bus_info['dkSum'];//带宽
            $parms['quota_dqzt'] = $bus_info['quotaIsdq'];//容量是否到期；0：未到期，1：已到期
			$parms['quota'] = $bus_info['quota'];//全部容量
			$parms['give_quota'] = $bus_info['giveQuota'];//赠送容量
			$parms['paid_quota'] = $bus_info['paidQuota'];//支付容量
            $parms['flow'] = $bus_info['totalFlow'];//全部流量
			$parms['paid_flow'] = $bus_info['paidFlow'];//支付流量
			$parms['give_flow'] = $bus_info['giveFlow'];//赠送流量
			$parms['use_flow'] = $bus_info['useFlow'];//已使用流量
            $parms['distatus'] = $bus_info['distatus'];//封停状态：0 正常，1，涉黄封停，2到期封停，3涉黄到期封停
			$parms['area_code'] = 4001;//地区编号
			$parms['access_key'] = $bus_info['accessKey'];//访问oss的Key
			$parms['secret_key'] = $bus_info['secretKey'];//访问oss的Secret
            $parms['product_name'] = '对象存储';
            $parms['product_id'] = '318';
            $parms['user_id'] = !$business_info['user_id'] ? '-1' : $business_info['user_id'];
            $parms['login_name'] = !$business_info['login_name'] ? '待转让会员' : $business_info['login_name'];
            $parms['access'] = $api_access;
            //这里更新的是Cloudstorage业务表的信息
            $Cloudstorage_model = $this->model();
            $Cloudstorage_update_res = $Cloudstorage_model->where(['id' => ['eq',$id]])->save($parms);
            if($Cloudstorage_update_res === false){
                if(empty($business_info_exists)){
                    //删除同步失败的新增业务
                    $where['id'] = $id;
                    $this->model()->where($where)->delete();
                }
                $this->model()->setError('服务器繁忙，同步失败，请重试');
                return false;
            }else{
                return true;
            }
        }else{
            if(empty($business_info_exists)){
                //删除同步失败的新增业务
                $where['id'] = $id;
                $this->model()->where($where)->delete();
            }
            //说明同步调用api出错了,将错误结果返回出去
            $this->model()->setError(business_code($result));
            return FALSE;
        }
    }

    /**
     * 删除对象存储的方法
     * @author: Guopeng
     * @param $id
     * @return bool
     */
    public function eraseCloudstorageBusiness($id){
        return $this->erase($this->firstOrFalse(['id' => ['eq',$id]]),GD::PTYPE_CLOUD_STORAGE);
    }
}